@@ -104,7 +104,7 @@ GameView::GameView(QWidget *parent, Game *game, QDockWidget *messagesDock, QDock
     m_gameMessage = new QLabel( this );
     m_gameMessage->setPalette( palette );
 
-    m_endTurnBtn = new QPushButton( i18n("End Turn"), this );
+    m_endTurnBtn = new QPushButton( i18nc("@action:button", "End Turn"), this );
     m_endTurnBtn->setFixedSize( m_endTurnBtn->sizeHint() );
     m_endTurnBtn->setPalette( palette );
 
@@ -117,7 +117,7 @@ GameView::GameView(QWidget *parent, Game *game, QDockWidget *messagesDock, QDock
     m_shipCountEdit->setPalette( palette );
     m_shipCountEdit->setEchoMode( QLineEdit::Password );
 
-    m_standingOrder = new QCheckBox(i18n("Standing order"), this);
+    m_standingOrder = new QCheckBox(i18nc("@option:check", "Standing order"), this);
     m_standingOrder->setEnabled(false);
     m_standingOrder->setPalette( palette );
     m_standingOrder->setCheckState(Qt::Unchecked);
@@ -287,7 +287,7 @@ GameView::turn()
             m_standingOrder->setEnabled(false);
             m_standingOrder->setCheckState(Qt::Unchecked);
             m_mapScene->unselectPlanet();
-            m_gameMessage->setText( i18n("%1: Select source planet...", m_game->currentPlayer()->coloredName()) );
+            m_gameMessage->setText( i18n("%1: Select source planet…", m_game->currentPlayer()->coloredName()) );
             setFocus();
         }
 
@@ -304,7 +304,7 @@ GameView::turn()
             m_shipCountEdit->setEnabled(false);
             m_standingOrder->setEnabled(false);
             m_mapScene->selectPlanet(sourcePlanet);
-            m_gameMessage->setText( i18n("%1: Select destination planet...", m_game->currentPlayer()->coloredName()) );
+            m_gameMessage->setText( i18n("%1: Select destination planet…", m_game->currentPlayer()->coloredName()) );
             setFocus();
         }
 
